
import os
import sys
import pyutilib.subprocess
import glob
import optparse

if sys.platform.startswith('win'):
    platform='win'
else:
    platform='linux'

def run(package, argv):
    parser = optparse.OptionParser(usage='svn_update [OPTIONS] <dirs>')

    parser.add_option('-v','--verbose',
        action='store_true',
        dest='verbose',
        default=False,
        help='Verbose output')
    parser.add_option('-p','--package',
        action='store',
        dest='pkg',
        default='pyutilib',
        help='Limit the coverage to this package')

    options, args = parser.parse_args(argv)

    if len(args) == 1:
        parser.print_help()
        sys.exit(1)

    if options.pkg != "":
        cpkg=' --cover-package='+options.pkg
    else:
        cpkg=''
    if options.verbose:
        vflag=' -v'
    else:
        vflag=''

    os.environ['COVERAGE_FILE'] = os.getcwd()+os.sep+'.coverage'

    dirs=set()
    dirs.add( os.getcwd() )
    for arg in args[1:]:
        for dir in glob.glob(arg+'*'):
            dirs.add(dir)

    cwd = os.path.dirname(os.getcwd())
    if platform == 'win':
        srcdirs=[]
        for dir in glob.glob('*'):
            if os.path.isdir(dir):
                srcdirs.append(os.path.abspath(dir))
        os.environ['PYTHONPATH']=os.pathsep.join(srcdirs)
        cmd =  os.sep.join([cwd,'Scripts','python.exe'])+' '+os.sep.join([sys.exec_prefix,'Scripts','nosetests-script.py'])+' --with-coverage --cover-erase'+vflag+cpkg+' --with-xunit --xunit-file=TEST-'+package+'.xml '+ " ".join(list(dirs))
        os.environ['PATH'] = cwd+os.sep+'Scripts'+os.pathsep+os.environ.get('PATH','')
    else:
        cmd = sys.exec_prefix+os.sep+'bin'+os.sep+'nosetests --with-coverage --cover-erase'+vflag+cpkg+' --with-xunit --xunit-file=TEST-'+package+'.xml '+ " ".join(list(dirs))
        os.environ['PATH'] = cwd+os.sep+'bin'+os.pathsep+os.environ.get('PATH','')
    print "Running... "+cmd
    print ""
    pyutilib.subprocess.run(cmd, tee=True)


def runPyUtilibTests():
    parser = optparse.OptionParser(usage='test.pyutilib [options] <dirs>')

    parser.add_option('-d','--dir',
        action='store',
        dest='dir',
        default=None,
        help='Top-level source directory where the tests are applied.')
    parser.add_option('--all',
        action='store_true',
        dest='all_cats',
        default=False,
        help='All tests are executed.')
    parser.add_option('--cat','--category',
        action='append',
        dest='cats',
        default=[],
        help='Specify test categories.')
    parser.add_option('-v','--verbose',
        action='store_true',
        dest='verbose',
        default=False,
        help='Verbose output')

    _options, args = parser.parse_args(sys.argv)

    #if len(args) == 1:
        #parser.print_help()
        #sys.exit(1)

    if _options.dir is None:
        os.chdir( os.path.dirname(os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))) )
    else:
        os.chdir( _options.dir )

    print "Running tests in directory",os.getcwd()
    if _options.all_cats is True:
        _options.cats = []
    elif len(_options.cats) == 0:
        _options.cats = ['smoke']
    elif 'all' in _options.cats:
        _options.cats = []
    if len(_options.cats) > 0:
        os.environ['PYUTILIB_UNITTEST_CATEGORIES'] = ",".join(_options.cats)
        print " ... for test categories: "+ os.environ['PYUTILIB_UNITTEST_CATEGORIES']
    options=[]
    if _options.verbose:
        options.append('-v')
    if len(args) == 1:
        dirs=['pyutilib']
    else:
        dirs=[]
        for dir in args:
            if dir.startswith('-'):
                options.append(dir)
            elif dir.startswith('pyutilib'):
                dirs.append(dir)
            else:
                dirs.append('pyutilib.'+dir)
        if len(dirs) == 0:
            dirs = ['pyutilib']
    pyutilib.dev.runtests.run('pyutilib',['runtests']+options+['-p','pyutilib']+dirs)

